Task: Personalized Dialog Full Set
===================================
Description: Simulated dataset of restaurant booking focused on personalization based on user profiles. From Joshi et al. '17. 

Link: https://arxiv.org/abs/1706.07503

Tags: #personalized-dialog-full, #All, #Goal, #Personalization



Task: Personalized Dialog Small Set
====================================
Description: Simulated dataset of restaurant booking focused on personalization based on user profiles. From Joshi et al. '17. 

Link: https://arxiv.org/abs/1706.07503

Tags: #personalized-dialog-small, #All, #Goal, #Personalization

